@@ -22,6 +22,7 @@ from .Fork import Fork
 from .ErrorMs import ErrorMs
 from .Util import validForksConf, getItemBy
 from .version_framework import version
+from http.server import BaseHTTPRequestHandler, HTTPServer
 
 if os.environ.get('KAFKA', None):
     from .ms_base import KafkaBase as BaseClass
@@ -148,10 +149,10 @@ class Microservices(BaseClass, ABC):
                     'param': 1,
                 },
                 'local_agent': {
-                    'reporting_host': os.environ.get('JAEGER_AGENT_HOST', '127.0.0.1'),
+                    'reporting_host': os.environ.get('JAEGER_AGENT_HOST', 'jaeger-agent.logging'),
                     'reporting_port': os.environ.get('JAEGER_AGENT_PORT', 6831),
                 },
-                'logging': True,
+                'logging': True if os.environ.get('PRODUCTION', False) else False,
                 'tags': {
                     '@coppel-py-version': version
                 }
@@ -176,8 +177,6 @@ class Microservices(BaseClass, ABC):
 
     def startHttpHealthCheck(self, healthcheck, smoketest):
         if os.environ.get('PRODUCTION', False):
-            from http.server import BaseHTTPRequestHandler, HTTPServer
-
             class myHandler(BaseHTTPRequestHandler):
                 def do_GET(self):
                     message_parts = []
@@ -200,9 +199,12 @@ class Microservices(BaseClass, ABC):
                     self.end_headers()
                     self.wfile.write(message.encode('utf-8'))
 
-        self.logs.info('[HealthCheck] listening on 0.0.0.0:80')
-        server = HTTPServer(('', 80), myHandler)
-        server.serve_forever()
+            self.logs.info('[HealthCheck] listening on 0.0.0.0:80')
+
+            server = HTTPServer(('', 80), myHandler)
+            server.serve_forever()
+        else:
+            self.logs.warn('HttpHealthCheck is Disabled')
 
     def coro_manager(self, coro):
         """
@@ -596,7 +598,7 @@ class Microservices(BaseClass, ABC):
                         },
                         "meta": {
                             "id_transaction": dataResponse['metadata']['id_transaction'],
-                            "status": 'ERROR' if errorCode < 0 else 'SUCCESS'
+                            "status": 'ERROR' if errorCode < 0 or errorCode > 0 else 'SUCCESS'
                         }
                     }
                 }
